#!/bin/bash

# Copyright (C) 2018-2021 Intel Corporation
# SPDX-License-Identifier: Apache-2.0


sudo rm -rf real-and-fake-face-detection
echo -e "\e[1;32m'real-and-fake-face-detection' dataset unistalled completely\e[0m"


