#!/bin/bash

# Copyright (C) 2018-2021 Intel Corporation
# SPDX-License-Identifier: Apache-2.0


echo "work in progress....."


echo -e "\e[1;31mFor further queries please follow below URL\e[0m"

echo -e "\e[1;32mhttps://www.kaggle.com/datasets/alxmamaev/flowers-recognition\e[0m"
