#!/bin/bash

# Copyright (C) 2018-2021 Intel Corporation
# SPDX-License-Identifier: Apache-2.0

pip3 install nncf[tf]
echo -e "\e[1;32mnncf is installed successfully\e[0m"

echo -e "\e[1;31mFor further queries please follow below URL\e[0m"

echo -e "\e[1;31mhttps://github.com/openvinotoolkit/nncf\e[0m"
