#!/bin/bash

# Copyright (C) 2018-2021 Intel Corporation
# SPDX-License-Identifier: Apache-2.0

# Creating a symbolic link 

unlink dl_streamer
echo -e "\e[1;32mDl-streamer Symbolic link Symbolic link Unlinked\e[0m"
