#!/bin/bash

# Copyright (C) 2018-2021 Intel Corporation
# SPDX-License-Identifier: Apache-2.0

# Creating a symbolic link 

ln -s /opt/intel/openvino_2021/data_processing/dl_streamer/ .

echo -e "\e[1;31mDl-streamer Symbolic link created in workload folder\e[0m"

echo -e "\e[1;32m\nFollow the README.md in the respective folders for usage\e[0m"

