#!/bin/bash

# Copyright (C) 2018-2021 Intel Corporation
# SPDX-License-Identifier: Apache-2.0

#installing benchmark-tool
ln -s /opt/intel/openvino_2021/deployment_tools/tools/ .

echo -e "\e[1;31mOMZ-tools Symbolic link created in workload folder\e[0m"

echo -e "\e[1;32m\nFollow the README.md for usage\e[0m"



